@@ -4,16 +4,16 @@
 
 MaxArrayDataLen=8640 #(1 value/10sec for 24h), 6*24*60
 
-arrData=[[0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen]
+arrData=[[""]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [""]*MaxArrayDataLen, [0]*MaxArrayDataLen]
 
 #field 1:
-    #0 Time
+    #0 Time (String)
     #1 X movement
     #2 Y movement
     #3 Z movement
     #4 Sum of X+Y+Z Derivation
-    #5 Event notes
-    #6 Transformed
+    #5 Event notes (String)
+    #6 SleepFiler applied
 #field 2:
     # samples
 
